@@ -2,8 +2,6 @@
 set -euo pipefail
 
 PLAYWRIGHT_VERSION="1.35.0"
-TMPDIR="$PWD/venv-build"
-VENV_PATH=$TMPDIR/usr/share/ucs-test/playwright-venv
 
 pushd "$VENV_PATH" || exit 1
 bin/pip install "playwright==$PLAYWRIGHT_VERSION"
