@@ -2,9 +2,8 @@
 set -euo pipefail
 
 PYTEST_PLAYWRIGHT_VERSION="0.3.3"
-TMPDIR="$PWD/venv-build"
-VENV_PATH=$TMPDIR/usr/share/ucs-test/playwright-venv
 
 pushd "$VENV_PATH" || exit 1
 bin/pip install "pytest-playwright==$PYTEST_PLAYWRIGHT_VERSION"
+bin/pip install "pytest-repeat"
 popd
